@@ -60,6 +60,7 @@ def progressbar(
 @contextmanager
 def timeit(
     process_name: str = "No Description",
+    *args,
     logger: typing.Optional[logging.Logger] = None,
     precision=1,
 ) -> None:
@@ -80,15 +81,12 @@ def timeit(
     if logger is None:
         logger = logging
     start_time = time.time()
-    message = "Timing Process: {0} ...".format(process_name)
-    logger.log(logging.INFO, message)
+    logger.log(logging.INFO, "Timing Process: " + process_name + " ...", *args)
 
     yield
 
     logger.log(
         logging.INFO,
-        "\t\t\t\t\t\t... Process Duration:"
-        "{value:1.{precision}f} s".format(
-            value=time.time() - start_time, precision=precision
-        ),
+        "\t\t\t\t\t\t... Process Duration: %1." + str(int(precision)) + "f s",
+        time.time() - start_time,
     )
